#ifndef _ELM_WIDGET_ITEM_CONTAINER_EO_LEGACY_H_
#define _ELM_WIDGET_ITEM_CONTAINER_EO_LEGACY_H_

#ifndef _ELM_WIDGET_ITEM_CONTAINER_EO_CLASS_TYPE
#define _ELM_WIDGET_ITEM_CONTAINER_EO_CLASS_TYPE

typedef Eo Elm_Widget_Item_Container;

#endif

#ifndef _ELM_WIDGET_ITEM_CONTAINER_EO_TYPES
#define _ELM_WIDGET_ITEM_CONTAINER_EO_TYPES


#endif


#endif
